Learn R Programming

birte (version 1.8.1)

birteFitRidge: Fit ridge regression model given a defined set of active regulators.

Description

Given a most likely configuration of active regulators identified by biRte, this method fits a conventional ridge regression model to explain gene expression. This function is required, if one would like to use MAP based prediction of gene expression instead of Bayesian predictions (see birtePredict). To fit the ridge regression model the R-package ridge is employed, which provides an efficient tuning of the regularization hyperparameter.

Usage

birteFitRidge(model, mRNA.train, ref.cond=1)

Arguments

model
output of birteRun
mRNA.train
vector of gene expression values
ref.cond
condition to consider

Value

an object of class "cv.glmnet" (see cv.glmnet)

Details

In order to make predictions with the fitted ridge regression model (birtePredict) store it into a slot "fit.ridge" of the object returned by birteRun and birteLimma, respectively.

Examples

Run this code
# artificial data
data(humanNetworkSimul)
sim = simulateData(affinities2)
limmamRNA = limmaAnalysis(sim$dat.mRNA, design=NULL, "treated - control")

# burnin and sampling size is much too small in reality
result = birteLimma(dat.mRNA=sim$dat.mRNA, data.regulators=NULL, 
limmamRNA=limmamRNA, 
affinities=affinities2, niter=100, nburnin=100, thin=2)

fit.ridge = birteFitRidge(result, sim$dat.mRNA[,1])

Run the code above in your browser using DataLab